Extensions — textblob-de 0.4.2 documentation

# Extensions

Planned extensions
Extension | Purpose | Status (in private repo)
--- | --- | ---
`textblob-rftagger` | wrapper class for `RFTagger` | 95% completed
`textblob-cmd` | command-line wrapper for `TextBlob` | 50% completed
`textblob-stanfordparser` | wrapper class for `StanfordParser` | 25% completed
`textblob-berkeleyparser` | wrapper class for `BerkeleyParser` | 0% completed
`textblob-sent-align` | sentence alignment for parallel TextBlobs | 40% completed
`textblob-converters` | various input and output conversions | 20% completed

See also notes on Extensions in the documentation of the main package.